function [weighted_EM] = combineWeightedEdges(edgevotes_m, img_curve, sigma_val, para)
% combines individual edge votes from each fixation level by computing an
% average over the entire contour
%
% USAGE
%   [weighted_EM] = combineWeightedEdges(edgevotes_m, img_curve, sigma_val, para)
%
% INPUTS
%   edgevotes_m                     - edge votes per fixation [HxWxF]
%   img_curve                       - edge image [HxW]
%   sigma_val                       - sigma value for converting votes to
%   weights (see convertVotesToWeights.m)
%   para                            - parameters (see getPara.m)
%
% OUTPUTS
%   weighted_EM                     - weighted edges [HxW]
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

[~, ~, nFixations] = size(edgevotes_m);
weighted_EM_v = zeros(size(edgevotes_m));
parfor kk=1:nFixations
    edgevotes_cc = edgevotes_m(:,:,kk);
    % gets weights from edge votes
    edgevotes_comb = convertVotesToWeights(edgevotes_cc, img_curve, sigma_val);
    weighted_EM_v(:,:,kk) = edgevotes_comb;
end
% take max over all levels
weighted_EM = nanmax(weighted_EM_v, [], 3);
% set nan values back to zeros
weighted_EM(isnan(weighted_EM)) = 0;

end