function [weighted_EM] = convertVotesToWeights(edgevote_map_final, segbb_union, sigma)
% converts the discrete edge vote map and the segmentation boundaries into
% a gaussian smoothed weighted edgemap
%
% USAGE
%   [weighted_EM] = convertVotesToWeights(edgevote_map_final, segbb_union, sigma)
%
% INPUTS
%   edgevote_map_final              - current edge votes [HxW]
%   segbb_union                     - current edge image [HxW]
%   sigma                           - sigma value for exponential mapping
%   function
%
% OUTPUTS
%   weighted_EM                     - weighted edges [HxW]
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

[rIm, cIm] = size(edgevote_map_final);
%% convert to a true edgevote map -- a value for every valid edge
ind_p = find(edgevote_map_final > -Inf);
% exponential function for converting votes to weights
edgevotes_map_inv = 0.05 + 0.95.*exp(edgevote_map_final/(2*sigma));
% set -Inf values to Nans (for nanfilter to work)
edgevotes_map_inv_c = nan(rIm, cIm); edgevotes_map_inv_c(ind_p) = edgevotes_map_inv(ind_p);
% NAN smoothing kernel
width_k = [9 9];kernel_type = 'gausswin';
edgevote_s = ndnanfilter(edgevotes_map_inv_c, kernel_type, width_k); % ignores nan values 
% combine with segmentation boundary
weighted_EM = segbb_union.*edgevote_s;

end