function [fig_handle] = dispTorqueMaxMin(torqueFinal_mat, torqueFixations_mat_cell, img, para)
% display torque max/min fixations + fixations over input rgb image
%
% USAGE
%   [fig_handle] = dispTorqueMaxMin(torqueFinal_mat, torqueFixations_mat_cell, img, para)
%
% INPUTS
%   torqueFinal_mat             - ranked torque value map
%   torqueFixations_mat_cell    - ranked torque fixations indices
%   img                         - rgb image
%   para                        - parameters (see getPara.m)
% 
% OUTPUTS
%   fig_handle                  - handle for torque output display
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!


[rImg, cImg] = size(torqueFinal_mat);
% top ranked torque map with extrema
torqueFinal = torqueFinal_mat(:,:,1);           
tMapMax = max( torqueFinal(:) );
tMapMin = min( torqueFinal(:) );
if tMapMax >= -tMapMin
    tMapMin = -tMapMax;
else
    tMapMax = -tMapMin;
end
fig_handle = figure; 
imagesc( torqueFinal_mat(:,:,1), [tMapMin, tMapMax]); colorbar;
colormap jet; hold on
torqueMaxValueMap = torqueFixations_mat_cell{1}{1,2}; torqueMinValueMap = torqueFixations_mat_cell{1}{1,1};
[iiMax, jjMax] = ind2sub([rImg/para.torque.resizeFactor cImg/para.torque.resizeFactor],... 
    torqueMaxValueMap(:,1));
[iiMin, jjMin] = ind2sub([rImg/para.torque.resizeFactor cImg/para.torque.resizeFactor],... 
    torqueMinValueMap(:,1));
for jj=1:min(size( torqueMaxValueMap, 1 ), para.disp.nFixations)
     plot(jjMax(jj), iiMax(jj), 'wx', 'markersize', 11, 'linewidth', 3 );
     text(jjMax(jj)+6, iiMax(jj)+6, int2str(jj), 'Color', 'white', 'FontSize', 15, 'FontWeight', 'bold');
end
for jj=1:min(size( torqueMinValueMap, 1 ), para.disp.nFixations)
    plot(jjMin(jj), iiMin(jj), 'kx', 'markersize', 11, 'linewidth', 3 );
    text(jjMin(jj)+6, iiMin(jj)+6, int2str(jj), 'Color', 'black', 'FontSize', 15, 'FontWeight', 'bold');
end
title('Modulated Torque'); hold off;

% also show torque points overlaid on rgb image
figure, imagesc(img); hold on;
for jj=1:min(size( torqueMaxValueMap, 1 ), 1)
     plot(jjMax(jj), iiMax(jj), 'rx', 'markersize', 11, 'linewidth', 3 );
     text(jjMax(jj)+6, iiMax(jj)+6, int2str(jj), 'Color', 'red', 'FontSize', 15, 'FontWeight', 'bold');
end
for jj=1:min(size( torqueMinValueMap, 1 ), 1)
    plot(jjMin(jj), iiMin(jj), 'gx', 'markersize', 11, 'linewidth', 3 );
    text(jjMin(jj)+6, iiMin(jj)+6, int2str(jj), 'Color', 'green', 'FontSize', 15, 'FontWeight', 'bold');
end
title('Detected object location (top 2): red (max), green (min)'); hold off;

end
