function [edges,thetaI] = computeEdges( im, img_curve, num_orient )
% compute edges for integral torque, splits edges into 8 different directions
%
% USAGE
%   [edges,thetaI] = computeEdges( im, img_curve, num_orient )
%
% INPUTS
%   im                          - rgb image [HxWx3]
%   img_curve                   - edge image [HxW]
%   num_orient                  - O, number of orientation bins (8)
% 
% OUTPUTS
%   edges                       - edge bins [HxWxO]
%   thetaI                      - orientation map [HxW]
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

if nargin < 3
    num_orient=8;
end
[~, ~, nDim] = size(im);
if nDim == 3
    imGray = rgb2gray( im );
else
    imGray = im;
end
[gx,gy] = gradient( imGray );edgeS = img_curve;
theta = atan2( -gx, gy );theta( gx==0 & gy==0 ) = NaN;thetaI=theta;
% split edges into eight directions
theta = theta + pi/num_orient;theta(theta<0) = theta(theta<0) + 2.0*pi;
edges = zeros([size(edgeS),num_orient]);
for i=1:num_orient
    mask = ( theta>=(i-1)/num_orient*2.0*pi & theta<i/num_orient*2.0*pi );
    edges(:,:,i) = edgeS .* mask;
end
    
end