function [xcon, ycon] = getThinCurve(frag_in, para)
% function to approximate an edge via a smooth curve
%
% USAGE
%   [xcon, ycon] = getThinCurve(frag_in, para)
%
% INPUTS
%   frag_in             - input edge points [Nx2]
%   para                - parameters (see getPara.m)
%
% OUTPUTS
%   [xcon, ycon]           - gaussian smoothed curve [Nx2] [x,y]
%
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

    % create gaussian smooth kernel
    GaussianDieOff = .0001; 
    pw = 1:para.edgeLength; 
    ssq = para.edge.sig*para.edge.sig;
    width = max(find(exp(-(pw.*pw)/(2*ssq))>GaussianDieOff));
    if isempty(width), width = 1; end
    t = (-width:width);gau = exp(-(t.*t)/(2*ssq))/(2*pi*ssq); 
    gau=gau/sum(gau);x = frag_in(:,2);y = frag_in(:,1);
    W = width;L = size(x,1);
    if L<=W, W = L-1; end        
    x1=[ones(W,1)*2*x(1)-x(W+1:-1:2);x;ones(W,1)*2*x(L)-x(L-1:-1:L-W)];
    y1=[ones(W,1)*2*y(1)-y(W+1:-1:2);y;ones(W,1)*2*y(L)-y(L-1:-1:L-W)];
    xx=conv(x1,gau); xx=xx(W+1:L+3*W);
    yy=conv(y1,gau); yy=yy(W+1:L+3*W); 
    valIndS = size(ones(W,1)*2*x(1)-x(W+1:-1:2),1) + 1;
    xcon = xx(valIndS:valIndS+size(x,1)-1); ycon = yy(valIndS:valIndS+size(y,1)-1);
end