function [x,y] = get_start_point(bwim)
% gets starting point of a contour image (bwim)
% 
% USAGE
%   [x,y] = get_start_point(bwim)
% 
% INPUTS
%   bwim        - input logical edge map [HxW]
% 
% OUTPUTS
%   x,y         - ordered [x,y] pixel locations corresponding to edges (1)
%   in bwim
% 
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

%bwim must include one edge.
f = inline('x(5) == 1 && sum(x(:)) <= 2');
lut = makelut(f,3);
A = applylut(bwim, lut);
[X,Y] = find(A ~= 0);
if (size(X,1) == 0)
    [candidatesX, candidatesY] = find(bwim ~= 0);
    x = candidatesX(1);
    y = candidatesY(1);
else
    x = X(1);
    y = Y(1);
end
end
