function [img_bound_out] = makeClosedContours(img_bound_in, varargin)
% closes an input contour image using morphological operations
%
% USAGE
%   [img_bound_out] = makeClosedContours(img_bound_in, varargin)
%
% INPUTS
%   img_bound_in            - input edges surrounding fixation pt
%   varargin                - sets gap-size (scalar), default is 5 pixels
%
% OUTPUTS
%   img_bound_out           - filled boundaries
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

% handle input variables
numvarargs = length(varargin);
if numvarargs > 1
    error('makeClosedContours:TooManyInputs', ...
        'requires at most 1 optional inputs');
elseif numvarargs == 1
    maxGapSize = varargin{1};
end
% use bwdist to fill in gaps
im_c = img_bound_in;bd_imc = bwdist(im_c);
if numvarargs == 0
    [ii_bd, jj_bd] = find(bd_imc < 5); % max gap size
else
     [ii_bd, jj_bd] = find(bd_imc < maxGapSize);
end
ind_bd = sub2ind(size(bd_imc), ii_bd, jj_bd);
im_cn = false(size(im_c));im_cn(ind_bd) = true;
im_ee = imfill(im_cn, 'holes');SE = strel('disk', 5);
im_ee_e = imerode(im_ee, SE); img_bound_out = im_ee_e;

end