function [bwim, pointCount] = order_pts(bwim, x, y, pointCount, connect)
% order a set of input point pairs  
%
% USAGE
%   [bwim, pointCount] = order_pts(bwim, x, y, pointCount, connect)
% 
% INPUTS
%   bwim        - input logical edge map [HxW]
%   [x,y]       - starting point [x,y] (see get_start_point.m)
%   pointCount  - a counter for recursive calls (set to 2)
%   connect     - connectivity (set to 8)
% 
% OUTPUTS
%   bwim        - output ordered points map [HxW]
%   pointCount  - counter for recursive calls
%
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

pointCount = max([2 pointCount]);
while (bwim(x,y) == 1)
    bwim(x,y) = pointCount;
    pointCount = pointCount + 1;
    neighborhood = bwim(x-1:x+1,y-1:y+1);
    if (connect == 8)
        neighborhood = neighborhood .* [1 1 1; 1 0 1; 1 1 1];
    else
        neighborhood = neighborhood .* [0 1 0; 1 0 1; 0 1 0];
    end
    neighborCount = sum(sum(neighborhood == 1));
    [neighborX, neighborY] = find(neighborhood == 1);
    if (neighborCount > 1)
        for i=1:neighborCount
            [bwim,pointCount] = order_pts(bwim, (x-2) + neighborX(i), (y-2) + neighborY(i), pointCount, connect);
        end
    elseif (neighborCount == 1)
        x = (x-2) + neighborX(1);
        y = (y-2) + neighborY(1);
    end 
end
end
