function [img_curve, labeled_img_curve] = preprocessEdges(edges,para)
% extract longer edges for matching
% 
% USAGE
%   [img_curve, labeled_img_curve] = preprocessEdges(edges,para)
%
% INPUTS
%   edges               - input edge map [HxW]
%   para                - parameters (see getPara.m)
%
% OUTPUTS
%   img_curve                - cleaned up edge map [HxW]
%   labeled_img_curve        - labeled contour map of img_curve [HxW]
% 
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

[rImg, cImg] = size(edges);
edges_t = edges > para.test.pbthresh;
% remove contours near the boundaries
edges_t(end-(para.border):end,:) = false; edges_t(1:para.border+1,:) = false;
edges_t(:,end-(para.border):end) = false; edges_t(:,1:para.border+1) = false;
img_curve = edges_t;        
% create numbered edge contours
img_curve_t = bwmorph(img_curve, 'thin', Inf); % thin curves first
[img_curve_list, ~] = edgelink(img_curve_t, para.edgeLength); % remove short edges
labeled_img_curve = zeros(rImg, cImg); nCurves = size(img_curve_list, 2);
for iii=1:nCurves
    cc_curves = img_curve_list{iii};
    ind_cc = sub2ind([rImg, cImg], cc_curves(:,1), cc_curves(:,2));
    labeled_img_curve(ind_cc) = iii;
end
% use this curve as the final img_curve
img_curve = labeled_img_curve > 0; img_curve = im2double(img_curve);

end