function [smooth_c] = smoothContour_edges(frag_in, para, varargin)
% smoothes contours using splines
%
% USAGE
%   [smooth_c] = smoothContour_edges(frag_in, para, varargin)
%
% INPUTS
%   frag_in             - input edge points [Nx2]
%   para                - parameters (see getPara.m)
%   varargin            - max length of smoothed edges
%
% OUTPUTS
%   smooth_c           - smoothed (interpolated) edge points [M>>Nx2]
%
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!


% handle input variables
numvarargs = length(varargin);
if numvarargs > 1
    error('smoothContour_edges:TooManyInputs', ...
        'requires at most 1 optional inputs');
elseif numvarargs == 1
    lengthOpt = varargin{1};
end
[xcon, ycon] = getThinCurve(frag_in, para); % thins the 2D edge using Gaussian smoothing
if size(xcon,1) >= 2 && size(ycon, 1) >=2 
    orig_space = 1:size(xcon,1);
    if numvarargs == 0
        interp_space = linspace(1,size(xcon,1), para.edgefeatures.splinelength);
    else
        interp_space = linspace(1,size(xcon,1), lengthOpt);
    end    
    % knots for spline
    knots = [xcon'; ycon'];
    % create spline
    splineXY = spline(orig_space, knots, interp_space);
    smooth_c = [splineXY(2,:)', splineXY(1,:)']; %[yspline, xspline];
else
    smooth_c = [];
end

end