function [weights] = findWeights(edges)
% Find weights for each pixels, giving lower weights to pixels having several edges
%
% USAGE
%  [weights] = findWeights(edges)
%
% INPUTS
%   edges                       - edge bins [HxWxO]
% 
% OUTPUTS
%   weights                     - edge weights [HxW]
%
% Copyright (C) 2012 Cornelia Fermüller, University of Maryland College Park, [fer-at-cfar.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

edgeCount = sum(double(edges), 3); % sum along third dimension
zeroWeights = (edgeCount==0); % where weight should be zero
edgeCount(zeroWeights) = 1; % set zeros to 1 to avoid division by zero
weights = ones(size(edgeCount));
weights = weights ./ edgeCount; 
weights(zeroWeights) = 0; % set weights to zero where there is no edges

end