function [sumStack] = integralStackImage(imageStack) 
% Computes integral images for fast torque computation
% Input: imageStack(:,:,:) is a stack of images
 
% Output: sumStack(:,:,:) is a stack of integral images

% Integral images for edges sum up to 1000 x 1000
% Order 1 moments for 1000 x 1000 images can sum up to 10^9
% Order 2 moments can sum up to 10^12; need to use double. int64 does not have addition operation
%
% Copyright (C) 2012 Cornelia Fermüller, University of Maryland College Park, [fer-at-cfar.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

sumCols = zeros(size(imageStack)); % used to sum edges column by column
sumStack = zeros(size(imageStack)); % used to sum sumColsEdges row by row
[nbRows,nbCols] = size(imageStack(:,:,1));
sumCols(:,1,:) = imageStack(:,1,:); % first column of sumColsEdges is same as edges
for iCol = 2:nbCols, sumCols(:,iCol,:) = sumCols(:,iCol-1,:) + imageStack(:,iCol,:);end
sumStack(1,:,:) = sumCols(1,:,:); % first row of sumRowsEdges is same as sumColsEdges
for iRow = 2:nbRows,sumStack(iRow,:,:) = sumStack(iRow-1,:,:) + sumCols(iRow,:,:);end

end
    

