function [momentArms] = makeMomentArms(nbRows, nbCols)
% Moment arms from top left corner of image to edges 
% for edge gradients at each pixels in directions N, NE, E, SE, S, SW, W, NW
% in that order
%
% USAGE
%   [momentArms] = makeMomentArms(nbRows, nbCols)
%
% INPUTS
%   nbRows                      - H of image
%   nbCols                      - W of image
% 
% OUTPUTS
%   momentArms                  - [HxWx8] torque moments
%
% Copyright (C) 2012 Cornelia Fermüller, University of Maryland College Park, [fer-at-cfar.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

halfSqrt2 = 0.5*sqrt(2);
pixelRows = repmat((1:nbRows)',[1,nbCols]); % row indices of all image pixels
pixelCols = repmat((1:nbCols),[nbRows,1]); % col indices of all image pixels 

% Unit vectors for 8 directions of moment arms for 8 edge gradient directions
armDirections = [ -1,         0;            % N: if edge gradient is N, edge vector with bright on right side is left to right, and arm is downward
                  -halfSqrt2, halfSqrt2;    % NE
                   0,         1;            % E
                   halfSqrt2, halfSqrt2;    % SE
                   1,         0;            % S
                   halfSqrt2,-halfSqrt2;    % SW
                   0,        -1;            % W
                  -halfSqrt2,-halfSqrt2];   % NW
                  
for iCount = 1:8
    momentArms(:,:,iCount) = armDirections(iCount,1)*pixelRows + armDirections(iCount,2)*pixelCols;
end

end