function [shiftedStack] = my3DShift(stack, shift3DVector) 
% Shift stack by shift3DVector(1) rows, shift3DVector(2) cols and shift3DVector(3) layers
% These can be positive or negative
% Use same format as stack came in
% NOTE: the image itself is translated by shiftVector, NOT the observation point in the image
%
% USAGE
%   [shiftedStack] = my3DShift(stack, shift3DVector) 
%
% INPUTS
%   stack                         - input integral image stack [HxWx8]
%   shift3DVector                 - amount of 3D shift needed [1x3]
% 
% OUTPUTS
%   shiftedStack                  - output shifted integral image stack [HxWx8]
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!


% Pad array with zeros using padarray
absShift = abs(shift3DVector);
paddedStack = padarray(stack, absShift, 'replicate', 'both');

% Circle-shift image
circleShifted = circshift(paddedStack, shift3DVector);
% Truncate circleShifted to remove extra padding and get back to stack size
shiftedStack = circleShifted(absShift(1)+1:end-absShift(1), ...
						absShift(2)+1:end-absShift(2), ....
						absShift(3)+1:end-absShift(3));
                    
end
