function [edgeContribution_cell] = computeEdgeContribution_XY( edges, edgeweights, pt, patchSize, para )
%
% computing torque contributions for every edge pixels to a 
% torque at a given point and patch size.
%
% USAGE
%   [edgeContribution_cell] = computeEdgeContribution_XY( edges, edgeweights, pt, patchSize, para )
%
% INPUTS
%   edges                   - edge bins [HxWxO]
%   edgeweights             - edge weights [HxW]
%   pt                      - torque fixation pts [Fx2]
%   patchSize               - torque fixation scales [Fx2]
%   para                    - parameters (see getPara.m)
%   
% OUTPUTS
%   edgeContribution_cell   - supporting edges per fixation {Fx1}
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

szEdges = size(edges);
if ~para.torque.doModTorque    
    weights_f = findWeights(edges);
else
    weights_f = findWeights(edges).*edgeweights;
end
replicatedWeights = repmat(weights_f, [1 1 8]);
weightedEdges = edges .* replicatedWeights;
momentArms = makeMomentArms(szEdges(1), szEdges(2));
% flip lr for [cols, rows] in pt
pt = fliplr(pt);
% save the edgeContribution per fixation pt
edgeContribution_cell = cell(size(pt,1),1);  
for i=1:min(size(pt,1),para.eval.topN)
    width = patchSize(i,1);
    height = patchSize(i,2);     
    normalizer = 2 * width * height;
    momentArmsFromCenter = momentArms - repmat(momentArms(pt(i,2),pt(i,1),:), szEdges(1:2));
    edgeContribution = momentArmsFromCenter .* weightedEdges;
    edgeContribution = edgeContribution/normalizer;        
    edgeContribution_cell{i,1} = sum(edgeContribution,3);
end