function [torqueVolume] = computeIntegralWeightedTorque(edgesC, EW_map_rw, patchListXY, para)
% compute weighted torque via integral images (fast)
%
% USAGE
%   [torqueVolume] = computeIntegralWeightedTorque(edgesC, EW_map_rw, patchListXY, para)
%
% INPUTS
%   edgesC                      - edge bins [HxWxO]
%   EW_map_rw                   - weighted edges [HxW]
%   patchListXY                 - torque search scales (patch sizes) [Sx2]
%   para                        - parameters (see getPara.m)
% 
% OUTPUTS
%   torqueVolume                - torque volume over S scales [HxWxS] 
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

szEdges = size(edgesC);
if ~para.torque.doModTorque
    weights_f = findWeights(edgesC);
else
    weights_f = findWeights(edgesC).*(EW_map_rw);
    if para.torque.normWeights % normalize -- for fair comparison
        weights_f = (weights_f - min(weights_f(:)))./(max(weights_f(:)-min(weights_f(:))));
    end
end
replicatedWeights = repmat(weights_f, [1 1 8]); weightedEdges = edgesC .* replicatedWeights;
% pre-compute the edge sums via integral images
sumEdges = integralStackImage(weightedEdges); momentArms = makeMomentArms(szEdges(1), szEdges(2));
moments = momentArms .* weightedEdges; sumMoments = integralStackImage(moments);
% pass in full XY (rectangular) patch sizes
torqueVolume = findMomentScaleStack_XY( momentArms, sumEdges, sumMoments, patchListXY, para);

end