function [patchHisto] = findAllPatchHistos_XY(integralStack, patchSizeXY) 
% Given a stack of integral images and a patch size
% Works for rectangular patches
% Generate a stack of 8 images 
% where each pixel value is the sum of counts in the patch centered at that pixel
% If the patch is straight, the shift directions are [-1, -1; 1, -1; 1, 1; -1, 1]
% If the patch is diagonal, the shift directions are [-1, 0; 0, -1; 1, 0; 0, 1]
% But this is a bit more complicated because diagonal patches have interlaced diagonal cumulations
% 3D shift is needed because the array being shifted is a 3D array
%
% USAGE
%   [patchHisto] = findAllPatchHistos_XY(integralStack, patchSizeXY) 
%
% INPUTS
%   integralStack               - stack of integral images [HxWx8]
%   patchSizeXY                 - current torque patch size [1x2]
% 
% OUTPUTS
%   patchHisto                  - sum of counts of patch centered at each pixel [HxWx8] 
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

halfSize = floor(0.5 .* patchSizeXY); % make all XY halfsize [Xsize, Ysize]
addVal = 0;
shiftVectors = [-halfSize(2)+addVal,-halfSize(1)+addVal; ...
                halfSize(2)-addVal+1,-halfSize(1)+addVal;...
                halfSize(2)-addVal+1,halfSize(1)-addVal+1;...
                -halfSize(2)+addVal,halfSize(1)-addVal+1;...  
                ];
patchHisto = zeros(size(integralStack));
for iCount = 1:size(shiftVectors,1)
	shift3D = [shiftVectors(iCount,:), 0]; % 3D vector, but third dimension is always 0 here
	shiftedStack = my3DShift(integralStack, shift3D);
	patchHisto = patchHisto + (-1)^(iCount-1) * shiftedStack; % signs alternate +,-,+,-
end

end