function [edgevotes_map] = computeEdgeVotesFromSegment_FFT(test_edges, objcat_dat,...
                            torqueCenter, rotAngle_V, para)
% pre-rotates the features points and returns edge votes scores
%
% USAGE
%   [edgevotes_map] = computeEdgeVotesFromSegment_FFT(test_edges, objcat_dat, torqueCenter, rotAngle_V, para)
%
% INPUTS
%   test_edges              - test edges to compare with model [HxW]
%   objcat_dat              - model data {4x1}
%   torqueCenter            - torque fixation center [y,x]
%   rotAngle_V              - estimated rotation [4x1]
%   para                    - parameters (see getPara.m)
%   
% OUTPUTS
%   edgevotes_map           - votes (scores) for test edges [HxW]
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!


[rIm, cIm] = size(test_edges);
% model
model_pts = objcat_dat{1};model_grads = objcat_dat{2};model_bw = objcat_dat{3};
SMod = regionprops(model_bw, 'Centroid'); model_center = SMod.Centroid; %[x,y]
% test contours
[feature_pts,feature_grads] = getPtSamplesFromContours(test_edges,para.sc.samp_freq);
% preprocess points
cont_c = 0.0;curv_c = 0.0;
% note X and Y here are inverted with respect to the image
mean_model_x = mean(model_pts(:,1)); mean_model_y = mean(model_pts(:,2));
model_pts(:,1) = model_pts(:,1) - mean_model_x;
model_pts(:,2) = model_pts(:,2) - mean_model_y;
max_model = max(max(model_pts)); model_pts = model_pts ./ max_model; 
model_cent_rs = zeros(1,2);
%INVERT X,Y
model_cent_rs(1) = (model_center(2) - mean_model_x)./max_model;
model_cent_rs(2) = (model_center(1) - mean_model_y)./max_model;
mean_feature_x = mean(feature_pts(:,1)); mean_feature_y = mean(feature_pts(:,2));
feature_pts(:,1) = feature_pts(:,1) - mean_feature_x;
feature_pts(:,2) = feature_pts(:,2) - mean_feature_y;
max_feature = max(max(feature_pts)); feature_pts = feature_pts ./ max_feature;
feature_center = torqueCenter; feature_cent_rs = zeros(1,2);
%INVERT X,Y
feature_cent_rs(1) = (feature_center(2) - mean_feature_x)./max_feature;
feature_cent_rs(2) = (feature_center(1) - mean_feature_y)./max_feature;
nAngles = size(rotAngle_V,1);mapping_cell = cell(nAngles,1);
sc_cost_cell = cell(nAngles,1);D_sc_v = zeros(nAngles,1);
%parfor RR=1:nAngles
for RR=1:nAngles
    [mapping_c, sc_cost_c] = matchTorqueShapeContext_FFT(model_pts, model_grads, model_cent_rs,...
         feature_pts, feature_grads, feature_cent_rs, cont_c, curv_c,1,2, para.sc.histcompType, -rotAngle_V(RR,1),para);   
     [a1, ~] = min(sc_cost_c, [], 1);[a2, ~] = min(sc_cost_c, [], 2);
     D_sc_v(RR,1) = max(mean(a1), mean(a2));sc_cost_cell{RR,1} = sc_cost_c;
     mapping_cell{RR,1} = mapping_c;
end
% find min D_sc_v
[~,ind_sel] = min(D_sc_v);sc_cost = sc_cost_cell{ind_sel,1};
mapping = mapping_cell{ind_sel,1};[~, map] = find(mapping);
% get cost for each map (match)
features_ind_m = mapping(map); ind_matchings = [map', features_ind_m']; %[model_ind, feature_ind]
[r_sc, c_sc] = size(sc_cost); ind_m = sub2ind([r_sc,c_sc], ind_matchings(:,1), ind_matchings(:,2));
cost_match = sc_cost(ind_m); cost_match(isinf(cost_match)) = NaN;% convert Infs to NaN
% get correspondences to compute procrustes distance
feature_coor = feature_pts(features_ind_m,:);model_coor = model_pts(map,:);
[Dist_prc,~,~] = procrustes(feature_coor, model_coor, 'scaling', true);
[a1, ~] = min(sc_cost, [], 1);[a2, ~] = min(sc_cost, [], 2);
D_sc = max(mean(a1), mean(a2));
alphaDprc = para.sc.alphaDprc;alphaDsc = para.sc.alphaDsc;
qual_match = alphaDprc*Dist_prc + alphaDsc*D_sc;
% get locations of matches
feature_match = feature_pts(ind_matchings(:,2),:);feature_match = feature_match .* max_feature;
feature_match(:,1) = round(feature_match(:,1) + mean_feature_x);
feature_match(:,2) = round(feature_match(:,2) + mean_feature_y);
ind_features = sub2ind([rIm, cIm], feature_match(:,1), feature_match(:,2));
cost_mat = [ind_features, cost_match]; % [index, cost_match]
edgevotes_map = nan(rIm, cIm);
if ~isempty(cost_mat),edgevotes_map(cost_mat(:,1)) = -qual_match; end
    
end