function [rotAngle_V] = estimateEdgeRotate_FFT(test_edges, objcat_dat)
% estimates pre-rotation using fft of radon
%
% USAGE
%   [rotAngle_V] = estimateEdgeRotate_FFT(test_edges, objcat_dat)
%
% INPUTS
%   test_edges              - edge image to compare with model [HxW]
%   objcat_dat              - model data {4x1}
%   
% OUTPUTS
%   rotAngle_V              - estimated rotation (4 possibilities) [4x1]
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

% model
model_edges = bwperim(objcat_dat{3},4); model_edges = im2double(model_edges);
% feature
feature_edges = im2double(test_edges); 
model_P = abs(fft(radon(model_edges))); feature_P = abs(fft(radon(feature_edges))); 
sModel = sum(model_P,1); sFeature = sum(feature_P,1);
sModel = sModel - mean(sModel); sFeature = sFeature - mean(sFeature);
% do cross correlation to determine rotational shift
[~,n] = max(xcorr(sFeature, sModel)); rotAngle_t = length(sFeature) - n + 1;
% return 4 possible interpretations
rotAngle_V = [rotAngle_t; 180+rotAngle_t; -rotAngle_t; 180-rotAngle_t];

end