function [para]=getPara()
% gets default parameters for contour-based torque detection
% 
% USAGE
%  [para]=getPara()
% 
% OUTPUTS
%  para 	- default parameters
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

% I/O
para.test.model.dir = fullfile(pwd,'data', 'models');

% edges
para.test.pbthresh = 0.05;          % threshold for pb edges
para.edgeLength = 50; 
para.border = 3;
para.edge.gapsize = 2;
para.edge.interpMult = 2;

% torque
para.test.objsize_vect = [100 100]; % object size
para.torque.patchSkip = 10;
para.test.weighted.fPower = 2;
para.test.weighted.CCNPower = 2;
para.test.nonweighted.fPower = 1.4; %2 % smaller to smooth out torque fixations
para.torque.extremaWidth = 3;       % difference in intensity for local minima/maxima
para.torque.resizeFactor = 1;       % amount of pixels in x and y to skip (integers) = resize
para.eval.topN = 5;                 % max number of min/max fixations pts to consider
para.protoseg.pos_pct = 0.5;        % value of torque within this percentage of the center for pos masks
para.protoseg.neg_pct = 0.3;        % value of torque within this percentage from global min for neg masks
para.edge.sig = 5;
para.torque.normWeights = 0;        % normalized reweighted edges.

% shape-context parameters
para.sc.compareIndvContours = 1;
para.sc.sigma_val_cont = 0.05;
para.sc.sigma_val = 0.05;
para.sc.segdat_factor = 0.2; 
para.sc.pctile = 10;
para.sc.alphaContours = 0.5;
para.sc.alphaDprc = 0.2;
para.sc.alphaDsc = 0.8;
para.sc.angleRange = 2;
para.sc.n_dist	= 5;
para.sc.n_theta	= 12;
para.sc.mindist = 1/16;
para.sc.maxdist = 4;
para.sc.codonScales = 3;
para.sc.samp_freq   = 10;          % sample frequency of edge points
para.sc.minlength = 5;
para.sc.histcompType = 0;           % 0 - chi^2

% training to get model contours
para.edge.contourMinLength = 1;
para.edgefeatures.splinelength = 50; 
para.train.minsplinelength = 5; 
% EM params for spline clustering (training)
para.EM.ops.method = 'lrm'; 
para.EM.NumEMStarts = 10;
para.EM.ops.IterLimit = 5000;
para.EM.ops.order = 5;

% display extra info
para.disp.opt = 0;
para.disp.nFixations = 5;

end
