function [samples, gradients] = getPtSamplesFromContours(edgeImage, frequency_of_sampling)
% From edgeImage retrieve ordered edge points
% 
% USAGE
%   [samples, gradients] = getPtSamplesFromContours(edgeImage, frequency_of_sampling)
%
% INPUTS
%   edgeImage               - input edge map [HxW]
%   frequency_of_sampling   - number of pixels between samplings along
%   edges (equidistant)
%
% OUTPUTS
%   samples                 - sampled points [Nx2]
%   gradients               - sampled points' gradients [Nx2]
% 
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!


[labeledim, num] = bwlabel(edgeImage,8); % get different contours

%Order the points in the edge image
pointCount = 2;
bwim = zeros(size(edgeImage));

for i=1:num
    [x,y] = get_start_point(labeledim == i);
    bwim = bwim .* (labeledim ~= i) + (labeledim == i);
    [bwim, pointCount] = order_pts(bwim, x, y, pointCount, 8);
end
%bwim should now contain pointCount points, each numbered from 
%2 -> # of points.
[samplesX, samplesY, vals] = find(bwim);
[sortedVals, ind] = sort(vals);
[picks] = find(mod(sortedVals,frequency_of_sampling) == 0);
samples = [samplesX(ind(picks)) samplesY(ind(picks))];
[gradientx, gradienty] = gradient(double(edgeImage));
gradients = [gradientx(sub2ind(size(gradientx),samples(:,1),samples(:,2))) gradienty(sub2ind(size(gradienty),samples(:,1),samples(:,2))) ];

end




