function [weightedEM_final] = getWeightedEdges(img_curve,edgevotes_Min,edgevotes_Max,para)
% Convert edge votes to weights
% 
% USAGE
%   [weightedEM_final] = getWeightedEdges(img_curve,edgevotes_Min,edgevotes_Max,para)
%
% INPUTS
%   img_curve           - edge image [HxW]
%   edgevotes_Min       - edge votes from torque minima [HxWxF]
%   edgevotes_Max       - edge votes from torque maxima [HxWxF]
%   para                - parameters (see getPara.m)
%
% OUTPUTS
%   weightedEM_final    - weighted edges [HxW]
% 
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

[rImg, cImg]=size(img_curve);sigma_val = para.sc.sigma_val;     
ttMin = nanmax(edgevotes_Min, [], 3);
if max(ttMin(:)) ~= Inf, weightedEM_final_Min = combineWeightedEdges(edgevotes_Min, img_curve, sigma_val, para);
else weightedEM_final_Min = zeros(rImg, cImg);
end
ttMax = nanmax(edgevotes_Max, [], 3);
if max(ttMax(:)) ~= Inf, weightedEM_final_Max = combineWeightedEdges(edgevotes_Max, img_curve, sigma_val, para);
else weightedEM_final_Max = zeros(rImg, cImg);
end
% Combine weights together
weightedEM_final=cat(3,weightedEM_final_Min,weightedEM_final_Max); weightedEM_final=sum(weightedEM_final,3)./2;

end