function [slength] = computeSplineLength(spline_c)
% function to compute the actual length of a spline
%
% USAGE
%   [slength] = computeSplineLength(spline_c)
% 
% INPUTS
%   spline_c                - spline coordinates [Lx2]
%
% OUTPUTS
%   slength                 - pixel length of spline_c
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

if ~isempty(spline_c)
    d1 = pdist(spline_c); % get L1 dist
    d1_sq = squareform(d1);
    d1_sq_s = circshift(d1_sq, [0 -1]); % shift to get the pairwise dist to neighbor in diag
    d_d1 = diag(d1_sq_s);
    slength = sum(d_d1(1:end-1)); % sum all neighbors up
else
    slength = 0;
end

end