function [contour_frag] = getSalientFragments(edge_pts_c, para)
% function that takes in the smoothed centered edges_pts and extract
% maximum curvature contours
%
% USAGE
%   [contour_frag] = getSalientFragments(edge_pts_c, para)
% 
% INPUTS
%   edge_pts_c              - smoothed edge pts [Kx2]
%   para                    - parameters (see getPara.m)
% 
% OUTPUTS
%   contour_frag            - R codons {Rx1}
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

contour_frag = [];curve = {};
curve{1,1} = edge_pts_c; % only 1 curve
if ~isempty(curve)
    curve_new = cell(1,size(curve,2));indx_corner = cell(1,size(curve,2));
    for i=1:size(curve_new,2)
        curve_c = curve{i};
        [curve_n, ~, ind_corners] = computeLocalCurvature(curve_c, para);
        curve_new{i} = curve_n; 
        indx_corner{i} = ind_corners;
    end
    % break up the contours at the max-curvature corners
    nCurves = size(curve_new, 2); j=0;
    for i=1:nCurves
       curr_c = curve_new{1,i};
       curr_cor_indx = indx_corner{1,i};
       % break up contour
       prev_sind = 1;
       for k=1:size(curr_cor_indx,1)
           contour_frag{j+1,1} = curr_c(prev_sind:curr_cor_indx(k,1),:);
           prev_sind = curr_cor_indx(k,1)+1;
           j = j+1;
       end
       contour_frag{j+1,1} = curr_c(prev_sind:end,:);
       j = j+1;
    end
end

end