function [model_curves_cell] = preprocessModel(model_hd, para)
% creates splined smoooth model curves so that we can use them later for
% centering
%
% USAGE
%   [model_curves_cell] = preprocessModel(model_hd, para)
% 
% INPUTS
%   model_hd                - model logical mask [IxJ]
%   para                    - parameters (see getPara.m)
% 
% OUTPUTS
%   model_curves_cell       - coordinates [y,x] of extracted C contours {Cx1} 
%
% Copyright (C) 2014 Ching L Teo, University of Maryland College Park, [cteo-at-cs.umd.edu]
%
%    You can redistribute and/or modify this software for non-commercial use
%    under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    For commercial use, contact the author for licensing options. 
%
% Please email me if you find bugs, or have suggestions or questions!

[rIm, cIm] = size(model_hd);
% get regions
SS = regionprops(model_hd, 'PixelList');nRegions = size(SS, 1);
model_curves_cell = cell(nRegions, 1);
for ii=1:nRegions
    img_t = false(rIm, cIm);
    indx_v = sub2ind([rIm, cIm], SS(ii,1).PixelList(:,2), SS(ii,1).PixelList(:,1));
    img_t(indx_v) = true;img_e = bwperim(img_t, 4);
    curve = extract_curve(img_e,para.edge.gapsize, para.edgeLength);  
    nCurves = size(curve,2);
    % combine all curves together
    curve_s = [];
    for jj=1:nCurves
        curve_s = [curve_s; smoothContour_edges(curve{1,jj}, para, size(curve{1,jj},1)*3)];
    end
    model_curves_cell{ii,1} = curve_s; %[y , x]
end

end